@@ -176,7 +176,7 @@ END_TEST
 
 START_TEST(pad_button_intuos)
 {
-#if !HAVE_LIBWACOM_GET_BUTTON_EVDEV_CODE
+#if !HAVE_LIBWACOM
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
 	unsigned int code;
@@ -236,7 +236,7 @@ END_TEST
 
 START_TEST(pad_button_bamboo)
 {
-#if !HAVE_LIBWACOM_GET_BUTTON_EVDEV_CODE
+#if !HAVE_LIBWACOM
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
 	unsigned int code;
@@ -286,7 +286,7 @@ END_TEST
 
 START_TEST(pad_button_libwacom)
 {
-#if HAVE_LIBWACOM_GET_BUTTON_EVDEV_CODE
+#if HAVE_LIBWACOM
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
 	WacomDeviceDatabase *db = NULL;
@@ -916,38 +916,106 @@ START_TEST(pad_mode_group_has_no_toggle)
 }
 END_TEST
 
+static bool
+pad_has_keys(struct litest_device *dev)
+{
+	struct libevdev *evdev = dev->evdev;
+
+	return (libevdev_has_event_code(evdev, EV_KEY, KEY_BUTTONCONFIG) ||
+		libevdev_has_event_code(evdev, EV_KEY, KEY_ONSCREEN_KEYBOARD) ||
+	        libevdev_has_event_code(evdev, EV_KEY, KEY_CONTROLPANEL));
+}
+
+static void
+pad_key_down(struct litest_device *dev, unsigned int which)
+{
+	litest_event(dev, EV_ABS, ABS_MISC, 15);
+	litest_event(dev, EV_KEY, which, 1);
+	litest_event(dev, EV_SYN, SYN_REPORT, 0);
+}
+
+static void
+pad_key_up(struct litest_device *dev, unsigned int which)
+{
+	litest_event(dev, EV_ABS, ABS_MISC, 0);
+	litest_event(dev, EV_KEY, which, 0);
+	litest_event(dev, EV_SYN, SYN_REPORT, 0);
+}
+
+START_TEST(pad_keys)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+	unsigned int key;
+
+	if (!pad_has_keys(dev))
+		return;
+
+	litest_drain_events(li);
+
+	key = KEY_BUTTONCONFIG;
+	pad_key_down(dev, key);
+	libinput_dispatch(li);
+	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_PRESSED);
+
+	pad_key_up(dev, key);
+	libinput_dispatch(li);
+	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_RELEASED);
+
+	key = KEY_ONSCREEN_KEYBOARD;
+	pad_key_down(dev, key);
+	libinput_dispatch(li);
+	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_PRESSED);
+
+	pad_key_up(dev, key);
+	libinput_dispatch(li);
+	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_RELEASED);
+
+	key = KEY_CONTROLPANEL;
+	pad_key_down(dev, key);
+	libinput_dispatch(li);
+	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_PRESSED);
+
+	pad_key_up(dev, key);
+	libinput_dispatch(li);
+	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_RELEASED);
+}
+END_TEST
+
 TEST_COLLECTION(tablet_pad)
 {
-	litest_add("pad:cap", pad_cap, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:cap", pad_no_cap, LITEST_ANY, LITEST_TABLET_PAD);
+	litest_add(pad_cap, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_no_cap, LITEST_ANY, LITEST_TABLET_PAD);
 
-	litest_add("pad:time", pad_time, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_time, LITEST_TABLET_PAD, LITEST_ANY);
 
-	litest_add("pad:button", pad_num_buttons, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:button", pad_num_buttons_libwacom, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:button", pad_button_intuos, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:button", pad_button_bamboo, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:button", pad_button_libwacom, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:button", pad_button_mode_groups, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_num_buttons, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_num_buttons_libwacom, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_button_intuos, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_button_bamboo, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_button_libwacom, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_button_mode_groups, LITEST_TABLET_PAD, LITEST_ANY);
 
-	litest_add("pad:ring", pad_has_ring, LITEST_RING, LITEST_ANY);
-	litest_add("pad:ring", pad_ring, LITEST_RING, LITEST_ANY);
-	litest_add("pad:ring", pad_ring_finger_up, LITEST_RING, LITEST_ANY);
+	litest_add(pad_has_ring, LITEST_RING, LITEST_ANY);
+	litest_add(pad_ring, LITEST_RING, LITEST_ANY);
+	litest_add(pad_ring_finger_up, LITEST_RING, LITEST_ANY);
 
-	litest_add("pad:strip", pad_has_strip, LITEST_STRIP, LITEST_ANY);
-	litest_add("pad:strip", pad_strip, LITEST_STRIP, LITEST_ANY);
-	litest_add("pad:strip", pad_strip_finger_up, LITEST_STRIP, LITEST_ANY);
+	litest_add(pad_has_strip, LITEST_STRIP, LITEST_ANY);
+	litest_add(pad_strip, LITEST_STRIP, LITEST_ANY);
+	litest_add(pad_strip_finger_up, LITEST_STRIP, LITEST_ANY);
 
-	litest_add_for_device("pad:left_handed", pad_left_handed_default, LITEST_WACOM_INTUOS5_PAD);
-	litest_add_for_device("pad:left_handed", pad_no_left_handed, LITEST_WACOM_INTUOS3_PAD);
-	litest_add_for_device("pad:left_handed", pad_left_handed_ring, LITEST_WACOM_INTUOS5_PAD);
+	litest_add_for_device(pad_left_handed_default, LITEST_WACOM_INTUOS5_PAD);
+	litest_add_for_device(pad_no_left_handed, LITEST_WACOM_INTUOS3_PAD);
+	litest_add_for_device(pad_left_handed_ring, LITEST_WACOM_INTUOS5_PAD);
 	/* None of the current strip tablets are left-handed */
 
-	litest_add("pad:modes", pad_mode_groups, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:modes", pad_mode_groups_userdata, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:modes", pad_mode_groups_ref, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:modes", pad_mode_group_mode, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:modes", pad_mode_group_has, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:modes", pad_mode_group_has_invalid, LITEST_TABLET_PAD, LITEST_ANY);
-	litest_add("pad:modes", pad_mode_group_has_no_toggle, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_groups, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_groups_userdata, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_groups_ref, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_group_mode, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_group_has, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_group_has_invalid, LITEST_TABLET_PAD, LITEST_ANY);
+	litest_add(pad_mode_group_has_no_toggle, LITEST_TABLET_PAD, LITEST_ANY);
+
+	litest_add(pad_keys, LITEST_TABLET_PAD, LITEST_ANY);
 }
